==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'als articles futurs sonque (pas cap d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'als articles totes sens excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a totes los articles, levat los que lor forum es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (los utilizaires se devon abonar en donant lor adreiça e-mail abans de poder mandar de contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (las
 contribucions apareisson en public sonque se los administrators
 las an validadas).', # MODIF
	'bouton_radio_modere_abonnement' => 'amb abonament',
	'bouton_radio_modere_posteriori' => 'moderacion a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderacion a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar los messatges sul pic
 (las contribucions apareisson tre mandadas, los administrators las pòdon
 suprimir puèi).',

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca ?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Podètz pas mai accedir a aqueles forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> vòstre messatge deu téner almens dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> vòstre títol deu téner almens tres caractèrs.',
	'forum_attention_trop_caracteres' => '<b>Atencion !</b> vòstre messatge es tròp long (@compte@ caractèrs) : per se poder  registrar, cal pas que passe @max@ caractèrs.', # MODIF
	'forum_avez_selectionne' => 'Avètz seleccionat :',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aicí</a> per contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aqueste forum es moderat a priòri: vòstra contribucion pareisserà pas qu’aprèp qu’un administrator del sit l’aja validada.', # MODIF
	'forum_lien_hyper' => '<b>Ligam ipertèxt</b> (opcional)', # MODIF
	'forum_message_definitif' => ' Messatge definitiu : mandar al sit',
	'forum_message_trop_long' => 'Vòstre messatge es tròp long. La longor maximala es de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Respondatz pas a aquel e-mail mas pel forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(se vòstre messatge se referís a un article publicat pel web, o a una pagina que baile mai d’informacions, podètz marcar çai sota lo títol de la pagina e son adreiça URL.)',
	'forum_poste_par' => 'Messatge mandat@parauteur@ que fa seguida a vòstre article « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Qual sètz ?</b> (opcional)', # MODIF
	'forum_texte' => 'Tèxt de vòstre messatge :', # MODIF
	'forum_titre' => 'Títol :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Validar aquela causida',
	'forum_voir_avant' => 'Veire lo messatge abans de lo mandar', # MODIF
	'forum_votre_email' => 'Vòstra adreiça e-mail :', # MODIF
	'forum_votre_nom' => 'Vòstre nom (o pseudonim):', # MODIF
	'forum_vous_enregistrer' => ' Per participar a
  aquel forum, primièr vos cal registrar. Mercés
  de marcar çai sota l’identificant personal qu’avètz recebut.
 Se sètz pas registrat/ada, avètz de',
	'forum_vous_inscrire' => 'vos inscriure. ',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit del forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Seguir/gerir los forums',
	'icone_supprimer_message' => 'Suprimir aquel messatge',
	'icone_valider_message' => 'Validar aquel messatge',
	'info_activer_forum_public' => '<i>Per activar los forums publics, volgatz causir lor mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela causida de moderacion :',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion dels forums publics. Los forums publics poiràn èsser autorizats al cas per cas suls articles; seràn proïbits sus las rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Mandadís dels forums als autors dels articles',
	'info_fonctionnement_forum' => 'Foncionament del forum:',
	'info_gauche_suivi_forum_2' => 'La pagina de <i>seguit dels forums</i> es una aisina de gestion del vòstre sit (mas es pas un espaci per discutir o per redigir). Aficha totas las contribucions dels forums del sit, tant las del sit public coma las de l’espaci privat e vos permet de gerir aquelas contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en espèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dels forums publics',
	'info_option_email' => 'Quora un vesitaire del sit manda un messatge nòu al forum
 associat a un article, se’n pòt avisar los autors
 de l’article per e-mail. Desiratz d’utilizar aquela opcion?', # MODIF
	'info_pas_de_forum' => 'Pas cap de forum',
	'item_activer_forum_administrateur' => 'Activar lo forum dels administrators',
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum dels administrators',

	// L
	'lien_reponse_article' => 'Responsa a l’article',
	'lien_reponse_breve_2' => 'Responsa a la brèva',
	'lien_reponse_rubrique' => 'Responsa a la rubrica',
	'lien_reponse_site_reference' => 'Responsa al sit referenciat :', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sens tèxt',

	// R
	'repondre_message' => 'Respondre a aquel messatge',

	// S
	'statut_original' => 'original',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat dels administrators',
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Seguit dels forums',
	'titre_page_forum_suivi' => 'Seguit dels forums',
];

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'als articles futurs sonque (pas cap d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'als articles totes sens excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a totes los articles, levat los que lor forum es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (los utilizaires se devon abonar en donant lor adreiça e-mail abans de poder mandar de contribucions).', # MODIF
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (las
 contribucions apareisson en public sonque se los administrators
 las an validadas).', # MODIF
	'bouton_radio_modere_abonnement' => 'amb abonament',
	'bouton_radio_modere_posteriori' => 'moderacion a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderacion a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar los messatges sul pic
 (las contribucions apareisson tre mandadas, los administrators las pòdon
 suprimir puèi).', # MODIF

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca ?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Podètz pas mai accedir a aqueles forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> vòstre messatge deu téner almens dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> vòstre títol deu téner almens tres caractèrs.',
	'forum_attention_trop_caracteres' => '<b>Atencion !</b> vòstre messatge es tròp long (@compte@ caractèrs) : per se poder  registrar, cal pas que passe @max@ caractèrs.', # MODIF
	'forum_avez_selectionne' => 'Avètz seleccionat :',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aicí</a> per contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aqueste forum es moderat a priòri: vòstra contribucion pareisserà pas qu’aprèp qu’un administrator del sit l’aja validada.', # MODIF
	'forum_lien_hyper' => '<b>Ligam ipertèxt</b> (opcional)', # MODIF
	'forum_message_definitif' => ' Messatge definitiu : mandar al sit',
	'forum_message_trop_long' => 'Vòstre messatge es tròp long. La longor maximala es de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Respondatz pas a aquel e-mail mas pel forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(se vòstre messatge se referís a un article publicat pel web, o a una pagina que baile mai d’informacions, podètz marcar çai sota lo títol de la pagina e son adreiça URL.)',
	'forum_poste_par' => 'Messatge mandat@parauteur@ que fa seguida a vòstre article « @titre@ ».', # MODIF
	'forum_qui_etes_vous' => '<b>Qual sètz ?</b> (opcional)', # MODIF
	'forum_texte' => 'Tèxt de vòstre messatge :', # MODIF
	'forum_titre' => 'Títol :', # MODIF
	'forum_url' => 'URL :', # MODIF
	'forum_valider' => 'Validar aquela causida',
	'forum_voir_avant' => 'Veire lo messatge abans de lo mandar', # MODIF
	'forum_votre_email' => 'Vòstra adreiça e-mail :', # MODIF
	'forum_votre_nom' => 'Vòstre nom (o pseudonim):', # MODIF
	'forum_vous_enregistrer' => ' Per participar a
  aquel forum, primièr vos cal registrar. Mercés
  de marcar çai sota l’identificant personal qu’avètz recebut.
 Se sètz pas registrat/ada, avètz de',
	'forum_vous_inscrire' => 'vos inscriure. ',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Seguit del forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Seguir/gerir los forums',
	'icone_supprimer_message' => 'Suprimir aquel messatge',
	'icone_valider_message' => 'Validar aquel messatge',
	'info_activer_forum_public' => '<i>Per activar los forums publics, volgatz causir lor mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela causida de moderacion :',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion dels forums publics. Los forums publics poiràn èsser autorizats al cas per cas suls articles; seràn proïbits sus las rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Mandadís dels forums als autors dels articles', # MODIF
	'info_fonctionnement_forum' => 'Foncionament del forum:',
	'info_gauche_suivi_forum_2' => 'La pagina de <i>seguit dels forums</i> es una aisina de gestion del vòstre sit (mas es pas un espaci per discutir o per redigir). Aficha totas las contribucions dels forums del sit, tant las del sit public coma las de l’espaci privat e vos permet de gerir aquelas contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'es',
	'info_liens_syndiques_7' => 'en espèra de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit dels forums publics',
	'info_option_email' => 'Quora un vesitaire del sit manda un messatge nòu al forum
 associat a un article, se’n pòt avisar los autors
 de l’article per e-mail. Desiratz d’utilizar aquela opcion?', # MODIF
	'info_pas_de_forum' => 'Pas cap de forum',
	'item_activer_forum_administrateur' => 'Activar lo forum dels administrators', # MODIF
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum dels administrators', # MODIF

	// L
	'lien_reponse_article' => 'Responsa a l’article',
	'lien_reponse_breve_2' => 'Responsa a la brèva',
	'lien_reponse_rubrique' => 'Responsa a la rubrica',
	'lien_reponse_site_reference' => 'Responsa al sit referenciat :', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sens tèxt',

	// R
	'repondre_message' => 'Respondre a aquel messatge',

	// S
	'statut_original' => 'original',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat dels administrators', # MODIF
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Seguit dels forums',
	'titre_page_forum_suivi' => 'Seguit dels forums',
];
